#pragma once

#include "stdafx.h"
#include "TipAppDataManager.h"
#include "DataContext.h"
#include "tipconst.h"
#include <atlpath.h>
#include "XMLDataProvider.h"

namespace tipcommon
{

	BOOL TipAppDataManager::LoadXmlDoc(LPCTSTR configxml_filename, BOOL bIncludePath /* = FALSE */, Locale::Type locale /* = Locale::Korean */)
	{
		TiXmlDocument xmlDoc;
		CString xmlPath;
		if (bIncludePath)
		{
			xmlPath = configxml_filename;
		}
		else
		{
			LPITEMIDLIST lpi;
			TCHAR pszPath[MAX_PATH] = {'\0',};

			SHGetSpecialFolderLocation(NULL, CSIDL_LOCAL_APPDATA, &lpi);
			SHGetPathFromIDList(lpi, pszPath);

			CoTaskMemFree(lpi);

			_tcscat_s(pszPath, MAX_PATH, _T("\\Ntalkbiz"));
			if(_waccess(pszPath, 0) == -1)
				_wmkdir(pszPath);

			xmlPath = pszPath;
			xmlPath += _T("\\");
			xmlPath += configxml_filename;
		}

		USES_CONVERSION;
		if (FALSE == xmlDoc.LoadFile(T2A(xmlPath)))
			return FALSE;

		TiXmlElement* pElement = xmlDoc.FirstChildElement("root");
		if(pElement == NULL)	return NULL;

		// Search Locale
		TCHAR LocalAttrName[10] = {0, };
		TCHAR LocaleName[10] = {0, };
		switch(locale)
		{
		case Locale::Korean:
			_tcscpy_s(LocaleName, 10, _T("ko-KR"));
			break;
		case Locale::English:
			_tcscpy_s(LocaleName, 10, _T("en-US"));
			break;
		case Locale::Japanese:
			_tcscpy_s(LocaleName, 10, _T("ja-JP"));
			break;
		case Locale::Chinese:
			_tcscpy_s(LocaleName, 10, _T("zh-CN"));
			break;
		default:
			_tcscpy_s(LocaleName, 10, _T("ko-KR"));
			break;
		}

		pElement = pElement->FirstChildElement("locale");
		if (!pElement)
			return FALSE;

		m_configDataContext = new SimpleMapDataContext; 
		XMLDataProvider xmlProvider(m_configDataContext);
		xmlProvider.Load(pElement);
		return TRUE;
	}

	CComVariant TipAppDataManager::GetProperty(LPCTSTR key)
	{
		ATLASSERT(m_configDataContext);
		return m_configDataContext->GetProperty(key);	
	}

	CString TipAppDataManager::GetProperty(Element::Type elementType)
	{
		const TCHAR RESOURCE_ELEMENT_NAME[] = _T("resource");
		const TCHAR VERSION_ELEMENT_NAME[] = _T("version");
		const TCHAR SERVERINFO_ELEMENT_NAME[] = _T("updaterinfo");

		LPCTSTR elementname = NULL;

		switch(elementType)
		{
		case Element::ResourceFileName:
			elementname = RESOURCE_ELEMENT_NAME;
 			break;
		case Element::Version:
			elementname = VERSION_ELEMENT_NAME;
			break;
		case Element::ServerInfo:
			elementname = SERVERINFO_ELEMENT_NAME;
			break;
		}

		CComVariant var = GetProperty(elementname);
		if (elementname != NULL && var.vt != VT_EMPTY) 
		{
			return CString(var.bstrVal);
		}

		return CString(_T(""));
	}
};